# Copyright (c) 2016 Hewlett-Packard Enterprise Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

import warnings

from tempest.lib.services.image.v1.image_members_client import \
    ImageMembersClient
from tempest.lib.services.image.v1.images_client import ImagesClient

__all__ = ['ImageMembersClient', 'ImagesClient']


warnings.warn(
    "The tempest.lib.services.image.v1 module (Image v1 APIs service "
    "clients) is deprecated in favor of tempest.lib.services.image.v2 "
    "(Image v2 APIs service clients) and will be removed once Tempest stop "
    "supporting stable Ussuri.", DeprecationWarning)
